# flespi_gateway_rest_api

FlespiGatewayRestApi - JavaScript client for flespi_gateway_rest_api
**DISCLAIMER**: This is a beta version of the flespi gateway API, in the process of being tested before its official release on 31 May, 2017. Being so, there is no guarantee that system architecture will not change until release date.  This API provides methods to set up and manage data flow channels from tracking devices to [flespi gateway](https://flespi.com/gateway) and further to your application. While raw data from devices comes in unparsed and fragmented way, flespi gateway takes on work to analyze incoming data from different types of hardware, registers it to unified-formatted messages and provides easy and reliable access to tracker's data for your software. Note that access to messages from trackers is provided in a **single reader** way, i.e. stable reading can be carried out by only one worker.  To perform operations above you need to specify FlespiToken key provided on entrance to your personal account (this key is to be passed in REST API call via header: **Authorization: FlespiToken XXXXXXXXXX**).  Detailed REST API description provided in [guidelines](https://flespi.com/api-guidelines). 
This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0
- Package version: 1.0
- Build package: io.swagger.codegen.languages.JavascriptClientCodegen

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

To publish the library as a [npm](https://www.npmjs.com/),
please follow the procedure in ["Publishing npm packages"](https://docs.npmjs.com/getting-started/publishing-npm-packages).

Then install it via:

```shell
npm install flespi_gateway_rest_api --save
```

#### git
#
If the library is hosted at a git repository, e.g.
https://github.com/YOUR_USERNAME/flespi_gateway_rest_api
then install it via:

```shell
    npm install YOUR_USERNAME/flespi_gateway_rest_api --save
```

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`,
perform the following (assuming *main.js* is your entry file):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var FlespiGatewayRestApi = require('flespi_gateway_rest_api');

var defaultClient = FlespiGatewayRestApi.ApiClient.instance;

// Configure API key authorization: FlespiToken
var FlespiToken = defaultClient.authentications['FlespiToken'];
FlespiToken.apiKey = "YOUR API KEY"
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//FlespiToken.apiKeyPrefix['Authorization'] = "Token"

var api = new FlespiGatewayRestApi.ChannelsApi()

var chSelector = ["chSelector_example"]; // {[String]} Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name=mask -name matches wildcard mask   - uri=mask - URI matches wildcard mask   - protocol_id=value - channel's protocol ID matches value   - protocol_name=mask - protocol's name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled=true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled=true,protocol_id=10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled=false | inactive channels from the list of channels with IDs 1,2,3 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
api.channelsChSelectorDelete(chSelector, callback);

```

## Documentation for API Endpoints

All URIs are relative to *https://flespi.io/gw*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*FlespiGatewayRestApi.ChannelsApi* | [**channelsChSelectorDelete**](docs/ChannelsApi.md#channelsChSelectorDelete) | **DELETE** /channels/{ch-selector} | Remove selected channels 
*FlespiGatewayRestApi.ChannelsApi* | [**channelsChSelectorGet**](docs/ChannelsApi.md#channelsChSelectorGet) | **GET** /channels/{ch-selector} | Get collection of channels matching filter parameters
*FlespiGatewayRestApi.ChannelsApi* | [**channelsChSelectorPut**](docs/ChannelsApi.md#channelsChSelectorPut) | **PUT** /channels/{ch-selector} | Change existing channels properties 
*FlespiGatewayRestApi.ChannelsApi* | [**channelsPost**](docs/ChannelsApi.md#channelsPost) | **POST** /channels | Create new channel 
*FlespiGatewayRestApi.CommandsqueueApi* | [**channelsChSelectorCommandsQueueCmdQueueSelectorDelete**](docs/CommandsqueueApi.md#channelsChSelectorCommandsQueueCmdQueueSelectorDelete) | **DELETE** /channels/{ch-selector}/commands-queue/{cmd-queue-selector} | Remove commands from queue 
*FlespiGatewayRestApi.CommandsqueueApi* | [**channelsChSelectorCommandsQueueCmdQueueSelectorGet**](docs/CommandsqueueApi.md#channelsChSelectorCommandsQueueCmdQueueSelectorGet) | **GET** /channels/{ch-selector}/commands-queue/{cmd-queue-selector} | Get commands from the queue 
*FlespiGatewayRestApi.CommandsqueueApi* | [**channelsChSelectorCommandsQueueCmdQueueSelectorPut**](docs/CommandsqueueApi.md#channelsChSelectorCommandsQueueCmdQueueSelectorPut) | **PUT** /channels/{ch-selector}/commands-queue/{cmd-queue-selector} | Change command&#39;s fields 
*FlespiGatewayRestApi.CommandsqueueApi* | [**channelsChSelectorCommandsQueuePost**](docs/CommandsqueueApi.md#channelsChSelectorCommandsQueuePost) | **POST** /channels/{ch-selector}/commands-queue | Add command to commands buffer 
*FlespiGatewayRestApi.CommandsresultApi* | [**channelsChSelectorCommandsResultDelete**](docs/CommandsresultApi.md#channelsChSelectorCommandsResultDelete) | **DELETE** /channels/{ch-selector}/commands-result | 
*FlespiGatewayRestApi.CommandsresultApi* | [**channelsChSelectorCommandsResultGet**](docs/CommandsresultApi.md#channelsChSelectorCommandsResultGet) | **GET** /channels/{ch-selector}/commands-result | 
*FlespiGatewayRestApi.ConnectionsApi* | [**channelsChSelectorConnectionsConnSelectorDelete**](docs/ConnectionsApi.md#channelsChSelectorConnectionsConnSelectorDelete) | **DELETE** /channels/{ch-selector}/connections/{conn-selector} | Close TCP connections 
*FlespiGatewayRestApi.ConnectionsApi* | [**channelsChSelectorConnectionsConnSelectorGet**](docs/ConnectionsApi.md#channelsChSelectorConnectionsConnSelectorGet) | **GET** /channels/{ch-selector}/connections/{conn-selector} | List active TCP connections 
*FlespiGatewayRestApi.ConnectionsterminalApi* | [**channelsChSelectorConnectionsConnSelectorTerminalDelete**](docs/ConnectionsterminalApi.md#channelsChSelectorConnectionsConnSelectorTerminalDelete) | **DELETE** /channels/{ch-selector}/connections/{conn-selector}/terminal | Disable terminal mode 
*FlespiGatewayRestApi.ConnectionsterminalApi* | [**channelsChSelectorConnectionsConnSelectorTerminalGet**](docs/ConnectionsterminalApi.md#channelsChSelectorConnectionsConnSelectorTerminalGet) | **GET** /channels/{ch-selector}/connections/{conn-selector}/terminal | Read incoming terminal data 
*FlespiGatewayRestApi.ConnectionsterminalApi* | [**channelsChSelectorConnectionsConnSelectorTerminalPost**](docs/ConnectionsterminalApi.md#channelsChSelectorConnectionsConnSelectorTerminalPost) | **POST** /channels/{ch-selector}/connections/{conn-selector}/terminal | Enable terminal mode for connection 
*FlespiGatewayRestApi.ConnectionsterminalApi* | [**channelsChSelectorConnectionsConnSelectorTerminalPut**](docs/ConnectionsterminalApi.md#channelsChSelectorConnectionsConnSelectorTerminalPut) | **PUT** /channels/{ch-selector}/connections/{conn-selector}/terminal | Send data via terminal connection 
*FlespiGatewayRestApi.LogsApi* | [**channelsChSelectorLogsGet**](docs/LogsApi.md#channelsChSelectorLogsGet) | **GET** /channels/{ch-selector}/logs | Get channel&#39;s significant events records 
*FlespiGatewayRestApi.MessagesApi* | [**channelsChSelectorMessagesDelete**](docs/MessagesApi.md#channelsChSelectorMessagesDelete) | **DELETE** /channels/{ch-selector}/messages | Remove unnecessary messages 
*FlespiGatewayRestApi.MessagesApi* | [**channelsChSelectorMessagesGet**](docs/MessagesApi.md#channelsChSelectorMessagesGet) | **GET** /channels/{ch-selector}/messages | Get new messages from specified channels 
*FlespiGatewayRestApi.ProtocolsApi* | [**protocolsProtocolSelectorGet**](docs/ProtocolsApi.md#protocolsProtocolSelectorGet) | **GET** /protocols/{protocol-selector} | Get protocols meeting filtering conditions


## Documentation for Models

 - [FlespiGatewayRestApi.Channel](docs/Channel.md)
 - [FlespiGatewayRestApi.ChannelCommandQueue](docs/ChannelCommandQueue.md)
 - [FlespiGatewayRestApi.ChannelCommandQueueChannelId](docs/ChannelCommandQueueChannelId.md)
 - [FlespiGatewayRestApi.ChannelCommandQueueExpires](docs/ChannelCommandQueueExpires.md)
 - [FlespiGatewayRestApi.ChannelCommandQueueId](docs/ChannelCommandQueueId.md)
 - [FlespiGatewayRestApi.ChannelCommandQueueIdent](docs/ChannelCommandQueueIdent.md)
 - [FlespiGatewayRestApi.ChannelCommandQueuePayload](docs/ChannelCommandQueuePayload.md)
 - [FlespiGatewayRestApi.ChannelCommandQueuePut](docs/ChannelCommandQueuePut.md)
 - [FlespiGatewayRestApi.ChannelCommandResult](docs/ChannelCommandResult.md)
 - [FlespiGatewayRestApi.ChannelCommandResultExecuted](docs/ChannelCommandResultExecuted.md)
 - [FlespiGatewayRestApi.ChannelCommandResultResponse](docs/ChannelCommandResultResponse.md)
 - [FlespiGatewayRestApi.ChannelCommandsQueuePost](docs/ChannelCommandsQueuePost.md)
 - [FlespiGatewayRestApi.ChannelConnection](docs/ChannelConnection.md)
 - [FlespiGatewayRestApi.ChannelConnectionChannelId](docs/ChannelConnectionChannelId.md)
 - [FlespiGatewayRestApi.ChannelConnectionEstablished](docs/ChannelConnectionEstablished.md)
 - [FlespiGatewayRestApi.ChannelConnectionId](docs/ChannelConnectionId.md)
 - [FlespiGatewayRestApi.ChannelConnectionIdent](docs/ChannelConnectionIdent.md)
 - [FlespiGatewayRestApi.ChannelConnectionIp](docs/ChannelConnectionIp.md)
 - [FlespiGatewayRestApi.ChannelConnectionTerminal](docs/ChannelConnectionTerminal.md)
 - [FlespiGatewayRestApi.ChannelConnectionTerminalGet](docs/ChannelConnectionTerminalGet.md)
 - [FlespiGatewayRestApi.ChannelEnabled](docs/ChannelEnabled.md)
 - [FlespiGatewayRestApi.ChannelId](docs/ChannelId.md)
 - [FlespiGatewayRestApi.ChannelLogmessage](docs/ChannelLogmessage.md)
 - [FlespiGatewayRestApi.ChannelLogsPeriod](docs/ChannelLogsPeriod.md)
 - [FlespiGatewayRestApi.ChannelMessage](docs/ChannelMessage.md)
 - [FlespiGatewayRestApi.ChannelMessageParameter](docs/ChannelMessageParameter.md)
 - [FlespiGatewayRestApi.ChannelMessageParameters](docs/ChannelMessageParameters.md)
 - [FlespiGatewayRestApi.ChannelName](docs/ChannelName.md)
 - [FlespiGatewayRestApi.ChannelPost](docs/ChannelPost.md)
 - [FlespiGatewayRestApi.ChannelProtocolId](docs/ChannelProtocolId.md)
 - [FlespiGatewayRestApi.ChannelProtocolName](docs/ChannelProtocolName.md)
 - [FlespiGatewayRestApi.ChannelPut](docs/ChannelPut.md)
 - [FlespiGatewayRestApi.ChannelUri](docs/ChannelUri.md)
 - [FlespiGatewayRestApi.Channels](docs/Channels.md)
 - [FlespiGatewayRestApi.ChannelsId](docs/ChannelsId.md)
 - [FlespiGatewayRestApi.Data](docs/Data.md)
 - [FlespiGatewayRestApi.Data1](docs/Data1.md)
 - [FlespiGatewayRestApi.Error](docs/Error.md)
 - [FlespiGatewayRestApi.InlineResponse200](docs/InlineResponse200.md)
 - [FlespiGatewayRestApi.InlineResponse2001](docs/InlineResponse2001.md)
 - [FlespiGatewayRestApi.InlineResponse2002](docs/InlineResponse2002.md)
 - [FlespiGatewayRestApi.InlineResponse2003](docs/InlineResponse2003.md)
 - [FlespiGatewayRestApi.InlineResponse2004](docs/InlineResponse2004.md)
 - [FlespiGatewayRestApi.InlineResponse2005](docs/InlineResponse2005.md)
 - [FlespiGatewayRestApi.InlineResponse2006](docs/InlineResponse2006.md)
 - [FlespiGatewayRestApi.InlineResponse2007](docs/InlineResponse2007.md)
 - [FlespiGatewayRestApi.InlineResponse2008](docs/InlineResponse2008.md)
 - [FlespiGatewayRestApi.InlineResponse2009](docs/InlineResponse2009.md)
 - [FlespiGatewayRestApi.Protocol](docs/Protocol.md)
 - [FlespiGatewayRestApi.ProtocolDescription](docs/ProtocolDescription.md)
 - [FlespiGatewayRestApi.ProtocolId](docs/ProtocolId.md)
 - [FlespiGatewayRestApi.ProtocolName](docs/ProtocolName.md)


## Documentation for Authorization


### FlespiToken

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

