# FlespiGatewayRestApi.ChannelsApi

All URIs are relative to *https://flespi.io/gw*

Method | HTTP request | Description
------------- | ------------- | -------------
[**channelsChSelectorDelete**](ChannelsApi.md#channelsChSelectorDelete) | **DELETE** /channels/{ch-selector} | Remove selected channels 
[**channelsChSelectorGet**](ChannelsApi.md#channelsChSelectorGet) | **GET** /channels/{ch-selector} | Get collection of channels matching filter parameters
[**channelsChSelectorPut**](ChannelsApi.md#channelsChSelectorPut) | **PUT** /channels/{ch-selector} | Change existing channels properties 
[**channelsPost**](ChannelsApi.md#channelsPost) | **POST** /channels | Create new channel 


<a name="channelsChSelectorDelete"></a>
# **channelsChSelectorDelete**
> ChannelsId channelsChSelectorDelete(chSelector)

Remove selected channels 

Remove all existing channels matching filtering parameters.  Request closes all active connections. Unsent commands to given connections would be canceled. 

### Example
```javascript
var FlespiGatewayRestApi = require('flespi_gateway_rest_api');
var defaultClient = FlespiGatewayRestApi.ApiClient.default;

// Configure API key authorization: FlespiToken
var FlespiToken = defaultClient.authentications['FlespiToken'];
FlespiToken.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//FlespiToken.apiKeyPrefix = 'Token';

var apiInstance = new FlespiGatewayRestApi.ChannelsApi();

var chSelector = ["chSelector_example"]; // [String] | Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name=mask -name matches wildcard mask   - uri=mask - URI matches wildcard mask   - protocol_id=value - channel's protocol ID matches value   - protocol_name=mask - protocol's name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled=true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled=true,protocol_id=10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled=false | inactive channels from the list of channels with IDs 1,2,3 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.channelsChSelectorDelete(chSelector, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **chSelector** | [**[String]**](String.md)| Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name&#x3D;mask -name matches wildcard mask   - uri&#x3D;mask - URI matches wildcard mask   - protocol_id&#x3D;value - channel&#39;s protocol ID matches value   - protocol_name&#x3D;mask - protocol&#39;s name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled&#x3D;true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled&#x3D;true,protocol_id&#x3D;10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled&#x3D;false | inactive channels from the list of channels with IDs 1,2,3  | 

### Return type

[**ChannelsId**](ChannelsId.md)

### Authorization

[FlespiToken](../README.md#FlespiToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="channelsChSelectorGet"></a>
# **channelsChSelectorGet**
> Channels channelsChSelectorGet(chSelector, opts)

Get collection of channels matching filter parameters

Get collection of channels matching filter parameters. Use special keyword \&quot;all\&quot; to retreieve all channels. 

### Example
```javascript
var FlespiGatewayRestApi = require('flespi_gateway_rest_api');
var defaultClient = FlespiGatewayRestApi.ApiClient.default;

// Configure API key authorization: FlespiToken
var FlespiToken = defaultClient.authentications['FlespiToken'];
FlespiToken.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//FlespiToken.apiKeyPrefix = 'Token';

var apiInstance = new FlespiGatewayRestApi.ChannelsApi();

var chSelector = ["chSelector_example"]; // [String] | Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name=mask -name matches wildcard mask   - uri=mask - URI matches wildcard mask   - protocol_id=value - channel's protocol ID matches value   - protocol_name=mask - protocol's name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled=true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled=true,protocol_id=10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled=false | inactive channels from the list of channels with IDs 1,2,3 

var opts = { 
  'fields': ["fields_example"] // [String] | CSV-formatted list of JSON object fields to be returned in reply collection. 
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.channelsChSelectorGet(chSelector, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **chSelector** | [**[String]**](String.md)| Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name&#x3D;mask -name matches wildcard mask   - uri&#x3D;mask - URI matches wildcard mask   - protocol_id&#x3D;value - channel&#39;s protocol ID matches value   - protocol_name&#x3D;mask - protocol&#39;s name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled&#x3D;true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled&#x3D;true,protocol_id&#x3D;10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled&#x3D;false | inactive channels from the list of channels with IDs 1,2,3  | 
 **fields** | [**[String]**](String.md)| CSV-formatted list of JSON object fields to be returned in reply collection.  | [optional] 

### Return type

[**Channels**](Channels.md)

### Authorization

[FlespiToken](../README.md#FlespiToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="channelsChSelectorPut"></a>
# **channelsChSelectorPut**
> Channels channelsChSelectorPut(chSelectordata, opts)

Change existing channels properties 

Change properties of existing channels matching filter parameters.  All active connections to the channels will be closed before updates. 

### Example
```javascript
var FlespiGatewayRestApi = require('flespi_gateway_rest_api');
var defaultClient = FlespiGatewayRestApi.ApiClient.default;

// Configure API key authorization: FlespiToken
var FlespiToken = defaultClient.authentications['FlespiToken'];
FlespiToken.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//FlespiToken.apiKeyPrefix = 'Token';

var apiInstance = new FlespiGatewayRestApi.ChannelsApi();

var chSelector = ["chSelector_example"]; // [String] | Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name=mask -name matches wildcard mask   - uri=mask - URI matches wildcard mask   - protocol_id=value - channel's protocol ID matches value   - protocol_name=mask - protocol's name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled=true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled=true,protocol_id=10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled=false | inactive channels from the list of channels with IDs 1,2,3 

var data = new FlespiGatewayRestApi.ChannelPut(); // ChannelPut | 

var opts = { 
  'fields': ["fields_example"] // [String] | CSV-formatted list of JSON object fields to be returned in reply collection. 
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.channelsChSelectorPut(chSelectordata, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **chSelector** | [**[String]**](String.md)| Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name&#x3D;mask -name matches wildcard mask   - uri&#x3D;mask - URI matches wildcard mask   - protocol_id&#x3D;value - channel&#39;s protocol ID matches value   - protocol_name&#x3D;mask - protocol&#39;s name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled&#x3D;true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled&#x3D;true,protocol_id&#x3D;10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled&#x3D;false | inactive channels from the list of channels with IDs 1,2,3  | 
 **data** | [**ChannelPut**](ChannelPut.md)|  | 
 **fields** | [**[String]**](String.md)| CSV-formatted list of JSON object fields to be returned in reply collection.  | [optional] 

### Return type

[**Channels**](Channels.md)

### Authorization

[FlespiToken](../README.md#FlespiToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="channelsPost"></a>
# **channelsPost**
> Channels channelsPost(data, opts)

Create new channel 

Create new channel listening for messages from tracking devices, working on specified protocol. To assign protocol either protocol_id or protocol_name should be specified. The channel will be created with automaticaly assigned unique **\&quot;host:port\&quot;** to listen for incoming connections from devices.  By default, start to receive data immediately after request. Use option **enabled**&#x3D;false to create inactive channel.  To receive **protocol_name** in response select this option in **fields** list. **protocol_name** is secondary parameter, so if **protocol_id** is specified then **protocol_name** will not be used. 

### Example
```javascript
var FlespiGatewayRestApi = require('flespi_gateway_rest_api');
var defaultClient = FlespiGatewayRestApi.ApiClient.default;

// Configure API key authorization: FlespiToken
var FlespiToken = defaultClient.authentications['FlespiToken'];
FlespiToken.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//FlespiToken.apiKeyPrefix = 'Token';

var apiInstance = new FlespiGatewayRestApi.ChannelsApi();

var data = [new FlespiGatewayRestApi.ChannelPost()]; // [ChannelPost] | 

var opts = { 
  'fields': ["fields_example"] // [String] | CSV-formatted list of JSON object fields to be returned in reply collection. 
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.channelsPost(data, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **data** | [**[ChannelPost]**](ChannelPost.md)|  | 
 **fields** | [**[String]**](String.md)| CSV-formatted list of JSON object fields to be returned in reply collection.  | [optional] 

### Return type

[**Channels**](Channels.md)

### Authorization

[FlespiToken](../README.md#FlespiToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

