/**
 * flespi gateway REST API 
 * **DISCLAIMER**: This is a beta version of the flespi gateway API, in the process of being tested before its official release on 31 May, 2017. Being so, there is no guarantee that system architecture will not change until release date.  This API provides methods to set up and manage data flow channels from tracking devices to [flespi gateway](https://flespi.com/gateway) and further to your application. While raw data from devices comes in unparsed and fragmented way, flespi gateway takes on work to analyze incoming data from different types of hardware, registers it to unified-formatted messages and provides easy and reliable access to tracker's data for your software. Note that access to messages from trackers is provided in a **single reader** way, i.e. stable reading can be carried out by only one worker.  To perform operations above you need to specify FlespiToken key provided on entrance to your personal account (this key is to be passed in REST API call via header: **Authorization: FlespiToken XXXXXXXXXX**).  Detailed REST API description provided in [guidelines](https://flespi.com/api-guidelines). 
 *
 * OpenAPI spec version: 1.0
 * 
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/ChannelPost', 'model/ChannelPut', 'model/Channels', 'model/ChannelsId'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/ChannelPost'), require('../model/ChannelPut'), require('../model/Channels'), require('../model/ChannelsId'));
  } else {
    // Browser globals (root is window)
    if (!root.FlespiGatewayRestApi) {
      root.FlespiGatewayRestApi = {};
    }
    root.FlespiGatewayRestApi.ChannelsApi = factory(root.FlespiGatewayRestApi.ApiClient, root.FlespiGatewayRestApi.ChannelPost, root.FlespiGatewayRestApi.ChannelPut, root.FlespiGatewayRestApi.Channels, root.FlespiGatewayRestApi.ChannelsId);
  }
}(this, function(ApiClient, ChannelPost, ChannelPut, Channels, ChannelsId) {
  'use strict';

  /**
   * Channels service.
   * @module api/ChannelsApi
   * @version 1.0
   */

  /**
   * Constructs a new ChannelsApi. 
   * @alias module:api/ChannelsApi
   * @class
   * @param {module:ApiClient} apiClient Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;


    /**
     * Callback function to receive the result of the channelsChSelectorDelete operation.
     * @callback module:api/ChannelsApi~channelsChSelectorDeleteCallback
     * @param {String} error Error message, if any.
     * @param {module:model/ChannelsId} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Remove selected channels 
     * Remove all existing channels matching filtering parameters.  Request closes all active connections. Unsent commands to given connections would be canceled. 
     * @param {Array.<String>} chSelector Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name&#x3D;mask -name matches wildcard mask   - uri&#x3D;mask - URI matches wildcard mask   - protocol_id&#x3D;value - channel&#39;s protocol ID matches value   - protocol_name&#x3D;mask - protocol&#39;s name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled&#x3D;true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled&#x3D;true,protocol_id&#x3D;10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled&#x3D;false | inactive channels from the list of channels with IDs 1,2,3 
     * @param {module:api/ChannelsApi~channelsChSelectorDeleteCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/ChannelsId}
     */
    this.channelsChSelectorDelete = function(chSelector, callback) {
      var postBody = null;

      // verify the required parameter 'chSelector' is set
      if (chSelector == undefined || chSelector == null) {
        throw new Error("Missing the required parameter 'chSelector' when calling channelsChSelectorDelete");
      }


      var pathParams = {
        'ch-selector': chSelector
      };
      var queryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['FlespiToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = ChannelsId;

      return this.apiClient.callApi(
        '/channels/{ch-selector}', 'DELETE',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the channelsChSelectorGet operation.
     * @callback module:api/ChannelsApi~channelsChSelectorGetCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Channels} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Get collection of channels matching filter parameters
     * Get collection of channels matching filter parameters. Use special keyword \&quot;all\&quot; to retreieve all channels. 
     * @param {Array.<String>} chSelector Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name&#x3D;mask -name matches wildcard mask   - uri&#x3D;mask - URI matches wildcard mask   - protocol_id&#x3D;value - channel&#39;s protocol ID matches value   - protocol_name&#x3D;mask - protocol&#39;s name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled&#x3D;true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled&#x3D;true,protocol_id&#x3D;10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled&#x3D;false | inactive channels from the list of channels with IDs 1,2,3 
     * @param {Object} opts Optional parameters
     * @param {Array.<module:model/String>} opts.fields CSV-formatted list of JSON object fields to be returned in reply collection. 
     * @param {module:api/ChannelsApi~channelsChSelectorGetCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Channels}
     */
    this.channelsChSelectorGet = function(chSelector, opts, callback) {
      opts = opts || {};
      var postBody = null;

      // verify the required parameter 'chSelector' is set
      if (chSelector == undefined || chSelector == null) {
        throw new Error("Missing the required parameter 'chSelector' when calling channelsChSelectorGet");
      }


      var pathParams = {
        'ch-selector': chSelector
      };
      var queryParams = {
        'fields': this.apiClient.buildCollectionParam(opts['fields'], 'csv')
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['FlespiToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = Channels;

      return this.apiClient.callApi(
        '/channels/{ch-selector}', 'GET',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the channelsChSelectorPut operation.
     * @callback module:api/ChannelsApi~channelsChSelectorPutCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Channels} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Change existing channels properties 
     * Change properties of existing channels matching filter parameters.  All active connections to the channels will be closed before updates. 
     * @param {Array.<String>} chSelector Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name&#x3D;mask -name matches wildcard mask   - uri&#x3D;mask - URI matches wildcard mask   - protocol_id&#x3D;value - channel&#39;s protocol ID matches value   - protocol_name&#x3D;mask - protocol&#39;s name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled&#x3D;true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled&#x3D;true,protocol_id&#x3D;10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled&#x3D;false | inactive channels from the list of channels with IDs 1,2,3 
     * @param {module:model/ChannelPut} data 
     * @param {Object} opts Optional parameters
     * @param {Array.<module:model/String>} opts.fields CSV-formatted list of JSON object fields to be returned in reply collection. 
     * @param {module:api/ChannelsApi~channelsChSelectorPutCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Channels}
     */
    this.channelsChSelectorPut = function(chSelector, data, opts, callback) {
      opts = opts || {};
      var postBody = data;

      // verify the required parameter 'chSelector' is set
      if (chSelector == undefined || chSelector == null) {
        throw new Error("Missing the required parameter 'chSelector' when calling channelsChSelectorPut");
      }

      // verify the required parameter 'data' is set
      if (data == undefined || data == null) {
        throw new Error("Missing the required parameter 'data' when calling channelsChSelectorPut");
      }


      var pathParams = {
        'ch-selector': chSelector
      };
      var queryParams = {
        'fields': this.apiClient.buildCollectionParam(opts['fields'], 'csv')
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['FlespiToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = Channels;

      return this.apiClient.callApi(
        '/channels/{ch-selector}', 'PUT',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the channelsPost operation.
     * @callback module:api/ChannelsApi~channelsPostCallback
     * @param {String} error Error message, if any.
     * @param {module:model/Channels} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Create new channel 
     * Create new channel listening for messages from tracking devices, working on specified protocol. To assign protocol either protocol_id or protocol_name should be specified. The channel will be created with automaticaly assigned unique **\&quot;host:port\&quot;** to listen for incoming connections from devices.  By default, start to receive data immediately after request. Use option **enabled**&#x3D;false to create inactive channel.  To receive **protocol_name** in response select this option in **fields** list. **protocol_name** is secondary parameter, so if **protocol_id** is specified then **protocol_name** will not be used. 
     * @param {Array.<module:model/ChannelPost>} data 
     * @param {Object} opts Optional parameters
     * @param {Array.<module:model/String>} opts.fields CSV-formatted list of JSON object fields to be returned in reply collection. 
     * @param {module:api/ChannelsApi~channelsPostCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/Channels}
     */
    this.channelsPost = function(data, opts, callback) {
      opts = opts || {};
      var postBody = data;

      // verify the required parameter 'data' is set
      if (data == undefined || data == null) {
        throw new Error("Missing the required parameter 'data' when calling channelsPost");
      }


      var pathParams = {
      };
      var queryParams = {
        'fields': this.apiClient.buildCollectionParam(opts['fields'], 'csv')
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['FlespiToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = Channels;

      return this.apiClient.callApi(
        '/channels', 'POST',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }
  };

  return exports;
}));
