/**
 * flespi gateway REST API 
 * **DISCLAIMER**: This is a beta version of the flespi gateway API, in the process of being tested before its official release on 31 May, 2017. Being so, there is no guarantee that system architecture will not change until release date.  This API provides methods to set up and manage data flow channels from tracking devices to [flespi gateway](https://flespi.com/gateway) and further to your application. While raw data from devices comes in unparsed and fragmented way, flespi gateway takes on work to analyze incoming data from different types of hardware, registers it to unified-formatted messages and provides easy and reliable access to tracker's data for your software. Note that access to messages from trackers is provided in a **single reader** way, i.e. stable reading can be carried out by only one worker.  To perform operations above you need to specify FlespiToken key provided on entrance to your personal account (this key is to be passed in REST API call via header: **Authorization: FlespiToken XXXXXXXXXX**).  Detailed REST API description provided in [guidelines](https://flespi.com/api-guidelines). 
 *
 * OpenAPI spec version: 1.0
 * 
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/Data1', 'model/InlineResponse2002', 'model/InlineResponse2004'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/Data1'), require('../model/InlineResponse2002'), require('../model/InlineResponse2004'));
  } else {
    // Browser globals (root is window)
    if (!root.FlespiGatewayRestApi) {
      root.FlespiGatewayRestApi = {};
    }
    root.FlespiGatewayRestApi.CommandsresultApi = factory(root.FlespiGatewayRestApi.ApiClient, root.FlespiGatewayRestApi.Data1, root.FlespiGatewayRestApi.InlineResponse2002, root.FlespiGatewayRestApi.InlineResponse2004);
  }
}(this, function(ApiClient, Data1, InlineResponse2002, InlineResponse2004) {
  'use strict';

  /**
   * Commandsresult service.
   * @module api/CommandsresultApi
   * @version 1.0
   */

  /**
   * Constructs a new CommandsresultApi. 
   * @alias module:api/CommandsresultApi
   * @class
   * @param {module:ApiClient} apiClient Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;


    /**
     * Callback function to receive the result of the channelsChSelectorCommandsResultDelete operation.
     * @callback module:api/CommandsresultApi~channelsChSelectorCommandsResultDeleteCallback
     * @param {String} error Error message, if any.
     * @param {module:model/InlineResponse2002} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Free finished commands until **delete_key** parameter. **delete_key** value may be taken from **last_key** value of previous GET commands-result request. This request is optional, normal method of work is to delete messages via GET /channels/.../commands-result request with **delete**&#x3D;true and valid **curr_key** from previous response.
     * @param {Array.<String>} chSelector Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name&#x3D;mask -name matches wildcard mask   - uri&#x3D;mask - URI matches wildcard mask   - protocol_id&#x3D;value - channel&#39;s protocol ID matches value   - protocol_name&#x3D;mask - protocol&#39;s name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled&#x3D;true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled&#x3D;true,protocol_id&#x3D;10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled&#x3D;false | inactive channels from the list of channels with IDs 1,2,3 
     * @param {module:model/Data1} data Parameters to delete already processed finished commands.
     * @param {module:api/CommandsresultApi~channelsChSelectorCommandsResultDeleteCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/InlineResponse2002}
     */
    this.channelsChSelectorCommandsResultDelete = function(chSelector, data, callback) {
      var postBody = data;

      // verify the required parameter 'chSelector' is set
      if (chSelector == undefined || chSelector == null) {
        throw new Error("Missing the required parameter 'chSelector' when calling channelsChSelectorCommandsResultDelete");
      }

      // verify the required parameter 'data' is set
      if (data == undefined || data == null) {
        throw new Error("Missing the required parameter 'data' when calling channelsChSelectorCommandsResultDelete");
      }


      var pathParams = {
        'ch-selector': chSelector
      };
      var queryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['FlespiToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = InlineResponse2002;

      return this.apiClient.callApi(
        '/channels/{ch-selector}/commands-result', 'DELETE',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }

    /**
     * Callback function to receive the result of the channelsChSelectorCommandsResultGet operation.
     * @callback module:api/CommandsresultApi~channelsChSelectorCommandsResultGetCallback
     * @param {String} error Error message, if any.
     * @param {module:model/InlineResponse2004} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Get executed or expired commands from specified channels. Request features: * Push mode: server will process request as soon as finished commands appear in the channel (or **timeout** expired) * It is assumed that only one handler has a possibility to delete commands. * If **delete** parameter is set and **curr_key** parameter is not empty all the commands up to specified **curr_key** are marked as read and processed.  Designated method of messages consumption is to use GET /channels/.../commands-result request with **timeout**&#x3D;XX (plus some optional limits) and **delete**&#x3D;true and valid **curr_key** from previous response. This will fetch only new executed or expired commands and automatically delete command instances received in previous request. Timeout parameter is wise to use when we need to wait until any new message will arrive to the channel and return then in immediately in response. 
     * @param {Array.<String>} chSelector Requested elements selecting template:   - **all** - choose all possible elements   - 1,2,3,... - choose elements by ID list  Use additional filter (CSV-formatted, applied with logical AND condition):   - name&#x3D;mask -name matches wildcard mask   - uri&#x3D;mask - URI matches wildcard mask   - protocol_id&#x3D;value - channel&#39;s protocol ID matches value   - protocol_name&#x3D;mask - protocol&#39;s name matches wildcard mask   - logs_period⋚value - logs storage period is greater, smaller or equal to value   - enabled&#x3D;true/false - if channel is in active/inactive mode  Request example | Description --------- | --------   /channels/all | all channels   /channels/1,2,3 | channels with IDs 1,2,3   /channels/enabled&#x3D;true,protocol_id&#x3D;10 | all active channels using protocol with ID 10   /channels/1,2,3,enabled&#x3D;false | inactive channels from the list of channels with IDs 1,2,3 
     * @param {Object} opts Optional parameters
     * @param {String} opts.data These parameters are used to receive finished commands and delete processed instances.
     * @param {module:api/CommandsresultApi~channelsChSelectorCommandsResultGetCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/InlineResponse2004}
     */
    this.channelsChSelectorCommandsResultGet = function(chSelector, opts, callback) {
      opts = opts || {};
      var postBody = null;

      // verify the required parameter 'chSelector' is set
      if (chSelector == undefined || chSelector == null) {
        throw new Error("Missing the required parameter 'chSelector' when calling channelsChSelectorCommandsResultGet");
      }


      var pathParams = {
        'ch-selector': chSelector
      };
      var queryParams = {
        'data': opts['data']
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = ['FlespiToken'];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = InlineResponse2004;

      return this.apiClient.callApi(
        '/channels/{ch-selector}/commands-result', 'GET',
        pathParams, queryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, callback
      );
    }
  };

  return exports;
}));
